@@ -70,6 +70,12 @@ TextToSpeechConfigWidget::TextToSpeechConfigWidget(QWidget *parent)
 
 TextToSpeechConfigWidget::~TextToSpeechConfigWidget() = default;
 
+void TextToSpeechConfigWidget::initializeSettings()
+{
+    readConfig();
+    slotAvailableEngineChanged();
+}
+
 void TextToSpeechConfigWidget::slotAvailableEngineChanged()
 {
     slotEngineChanged();
@@ -141,7 +147,7 @@ void TextToSpeechConfigWidget::restoreDefaults()
     mPitch->setValue(0);
     mVolume->setValue(50);
 
-    // TODO
+    // TODO load default value
 }
 
 void TextToSpeechConfigWidget::slotTestTextToSpeech()
