@@ -28,20 +28,21 @@ public:
     // engine name, i18n
     Q_REQUIRED_RESULT QMap<QString, QString> translatorEngineInfos() const;
 
-    Q_REQUIRED_RESULT QMap<TextTranslator::TranslatorUtil::Language, QString> supportedLanguages(const QString &clientName) const;
+    Q_REQUIRED_RESULT QMap<TextTranslator::TranslatorUtil::Language, QString> supportedFromLanguages(const QString &clientName) const;
+    Q_REQUIRED_RESULT QMap<TextTranslator::TranslatorUtil::Language, QString> supportedToLanguages(const QString &clientName) const;
 
     Q_REQUIRED_RESULT bool hasConfigurationDialog(const QString &clientName) const;
 
     Q_REQUIRED_RESULT QString fallbackFirstEngine() const;
 
-    void showConfigureDialog(const QString &clientName, QWidget *parentWidget);
+    Q_REQUIRED_RESULT bool showConfigureDialog(const QString &clientName, QWidget *parentWidget);
 
 Q_SIGNALS:
     void loadingTranslatorFailed();
 
 private:
-    void loadPlugins();
-    void loadPlugin(const QString &pluginPath);
+    TEXTTRANSLATOR_NO_EXPORT void loadPlugins();
+    TEXTTRANSLATOR_NO_EXPORT void loadPlugin(const QString &pluginPath);
     std::unique_ptr<TranslatorEngineLoaderPrivate> const d;
 };
 }
