@@ -53,10 +53,9 @@ public:
     void initLanguage();
     void fillToCombobox(const QString &lang);
 
-    QMap<TranslatorUtil::Language, QString> listLanguage;
     QByteArray data;
     TranslatorTextEdit *inputText = nullptr;
-    TranslatorResultTextEdit *translatorResultTextEdit = nullptr;
+    QPlainTextEdit *translatorResultTextEdit = nullptr;
     QComboBox *fromCombobox = nullptr;
     QComboBox *toCombobox = nullptr;
     QPushButton *translate = nullptr;
@@ -77,7 +76,8 @@ void TranslatorWidget::TranslatorWidgetPrivate::fillToCombobox(const QString &la
     toCombobox->clear();
 
     TranslatorUtil translatorUtil;
-    QMapIterator<TranslatorUtil::Language, QString> i(listLanguage);
+    const QMapIterator<TranslatorUtil::Language, QString> listToLanguage = translatorClient->supportedToLanguages();
+    QMapIterator<TranslatorUtil::Language, QString> i(listToLanguage);
     while (i.hasNext()) {
         i.next();
         const QString languageCode = TranslatorUtil::languageCode(i.key());
@@ -94,9 +94,9 @@ void TranslatorWidget::TranslatorWidgetPrivate::initLanguage()
     }
     toCombobox->clear();
     fromCombobox->clear();
-    listLanguage = translatorClient->supportedLanguages();
+    const QMapIterator<TranslatorUtil::Language, QString> listFromLanguage = translatorClient->supportedFromLanguages();
 
-    QMapIterator<TranslatorUtil::Language, QString> i(listLanguage);
+    QMapIterator<TranslatorUtil::Language, QString> i(listFromLanguage);
     TranslatorUtil translatorUtil;
     while (i.hasNext()) {
         i.next();
@@ -105,37 +105,6 @@ void TranslatorWidget::TranslatorWidgetPrivate::initLanguage()
     }
 }
 
-TranslatorResultTextEdit::TranslatorResultTextEdit(QWidget *parent)
-    : QPlainTextEdit(parent)
-{
-    setReadOnly(true);
-}
-
-void TranslatorResultTextEdit::setResultFailed(bool failed)
-{
-    if (mResultFailed != failed) {
-        mResultFailed = failed;
-        update();
-    }
-}
-
-void TranslatorResultTextEdit::paintEvent(QPaintEvent *event)
-{
-    if (mResultFailed) {
-        QPainter p(viewport());
-
-        QFont font = p.font();
-        font.setItalic(true);
-        p.setFont(font);
-
-        p.setPen(Qt::red);
-
-        p.drawText(QRect(0, 0, width(), height()), Qt::AlignCenter, i18n("Problem when connecting to the translator web site."));
-    } else {
-        QPlainTextEdit::paintEvent(event);
-    }
-}
-
 TranslatorTextEdit::TranslatorTextEdit(QWidget *parent)
     : QPlainTextEdit(parent)
 {
@@ -204,11 +173,17 @@ void TranslatorWidget::readConfig()
     if (from.isEmpty()) {
         return;
     }
-    const QString to = myGroup.readEntry(QStringLiteral("ToLanguage"));
     const int indexFrom = d->fromCombobox->findData(from);
     if (indexFrom != -1) {
         d->fromCombobox->setCurrentIndex(indexFrom);
     }
+    d->translatorClient->generateToListFromCurrentToLanguage(from);
+    // Update "to" combobox
+    d->toCombobox->blockSignals(true);
+    d->fillToCombobox(from);
+    d->toCombobox->blockSignals(false);
+
+    const QString to = myGroup.readEntry(QStringLiteral("ToLanguage"));
     const int indexTo = d->toCombobox->findData(to);
     if (indexTo != -1) {
         d->toCombobox->setCurrentIndex(indexTo);
@@ -317,12 +292,12 @@ void TranslatorWidget::init()
     d->splitter->setChildrenCollapsible(false);
     d->inputText = new TranslatorTextEdit(this);
     d->inputText->setObjectName(QStringLiteral("inputtext"));
-    d->inputText->setPlaceholderText(i18n("Drag text that you want to translate. (Be careful text will be send to Google Server)."));
+
     connect(d->inputText, &TranslatorTextEdit::textChanged, this, &TranslatorWidget::slotTextChanged);
     connect(d->inputText, &TranslatorTextEdit::translateText, this, &TranslatorWidget::slotTranslate);
 
     d->splitter->addWidget(d->inputText);
-    d->translatorResultTextEdit = new TranslatorResultTextEdit(this);
+    d->translatorResultTextEdit = new QPlainTextEdit(this);
     d->translatorResultTextEdit->setObjectName(QStringLiteral("translatedtext"));
     d->translatorResultTextEdit->setReadOnly(true);
     d->splitter->addWidget(d->translatorResultTextEdit);
@@ -369,6 +344,17 @@ void TranslatorWidget::switchEngine()
         connect(d->translatorPlugin, &TextTranslator::TranslatorEnginePlugin::translateFailed, this, &TranslatorWidget::slotTranslateFailed);
         d->initLanguage();
         d->engineNameLabel->setText(QStringLiteral("[%1]").arg(d->translatorClient->translatedName()));
+        d->invert->setVisible(d->translatorClient->hasInvertSupport());
+        updatePlaceHolder();
+    }
+}
+
+void TranslatorWidget::updatePlaceHolder()
+{
+    if (d->translatorClient->engineType() == TextTranslator::TranslatorEngineClient::Network) {
+        d->inputText->setPlaceholderText(i18n("Drag text that you want to translate. (Be careful text will be send to external Server)."));
+    } else {
+        d->inputText->setPlaceholderText(i18n("Drag text that you want to translate."));
     }
 }
 
@@ -388,6 +374,10 @@ void TranslatorWidget::slotFromLanguageChanged(int index, bool initialize)
     const QString lang = d->fromCombobox->itemData(index).toString();
     d->invert->setEnabled(lang != QLatin1String("auto"));
     const QString to = d->toCombobox->itemData(d->toCombobox->currentIndex()).toString();
+
+    // Get "from" language code for generating "to" language list
+    // qDebug() << " d->fromCombobox->currentIndex() " << lang;
+    d->translatorClient->generateToListFromCurrentToLanguage(lang);
     d->toCombobox->blockSignals(true);
     d->fillToCombobox(lang);
     d->toCombobox->blockSignals(false);
@@ -441,15 +431,13 @@ void TranslatorWidget::slotTranslateDone()
 {
     d->translate->setEnabled(true);
     d->progressIndicator->hide();
-    d->translatorResultTextEdit->setResultFailed(false);
     d->translatorResultTextEdit->setPlainText(d->translatorPlugin->resultTranslate());
 }
 
-void TranslatorWidget::slotTranslateFailed(bool signalFailed, const QString &message)
+void TranslatorWidget::slotTranslateFailed(const QString &message)
 {
     d->translate->setEnabled(true);
     d->progressIndicator->hide();
-    d->translatorResultTextEdit->setResultFailed(signalFailed);
     d->translatorResultTextEdit->clear();
     if (!message.isEmpty()) {
         KMessageBox::error(this, message, i18n("Translate error"));
